const path = require('path');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');

module.exports = (env) => {
    const pages = [
        {
            src: 'main',
            input: 'index.html',
            output: 'index.html',
            dir: './src/views/',
        },
    ];

    const config = {
        stats: { modules: false },
        context: __dirname,
        resolve: { extensions: ['.js', '.ts'] },
        entry: {
            main: './src/scripts/boot.ts',
            'site.css': './src/styles/site.scss',
        },
        output: {
            filename: '[name].js',
            publicPath: '/dist/',
        },
        module: {
            rules: [
                {
                    test: /\.ts$/,
                    include: path.join(__dirname, 'src', 'scripts'),
                    use: [
                        {
                            loader: 'ts-loader',
                            options: {
                                transpileOnly: true,
                            },
                        },
                    ],
                },
                {
                    test: /\.css$/,
                    use: ['style-loader', 'css-loader'],
                },
                {
                    test: /\.scss$/,
                    use: [
                        {
                            loader: 'style-loader',
                        },
                        {
                            loader: 'css-loader',
                            options: {
                                sourceMap: true,
                            },
                        },
                        {
                            loader: 'sass-loader',
                            options: {
                                sourceMap: true,
                            },
                        },
                    ],
                },
                {
                    test: /\.(png|jpg|jpeg|gif|svg)$/,
                    use: [
                        {
                            loader: 'url-loader',
                            options: {
                                limit: 25000,
                            },
                        },
                    ],
                },
                {
                    test: /\.html$/,
                    use: 'html-loader',
                },
            ],
        },
        plugins: [
            new webpack.DllReferencePlugin({
                context: __dirname,
                // eslint-disable-next-line global-require
                manifest: require('./assets/vendor-manifest.json'),
            }),
            new webpack.NamedModulesPlugin(),
            new webpack.HotModuleReplacementPlugin(),
            new webpack.ProvidePlugin({
                $: 'jquery',
                jQuery: 'jquery',
                'window.jQuery': 'jquery',
                Popper: ['popper.js', 'default'],
            }),
        ],
        // sass source maps broken when using ~ paths
        devtool: 'eval-source-map',
        devServer: {
            port: 9000,
            hot: true,
            publicPath: '/',
        },
    };

    pages.forEach((el) => {
        config.plugins.push(new HtmlWebpackPlugin({
            inject: false,
            chunks: [el.src, 'site.css', el.input],
            headInject: ['site.css'],
            bodyInject: [el.src],
            filename: el.output,
            template: './src/template.js',
            content: [el.input],
        }));
    });

    return [config];
};
